@@ -1,7 +1,7 @@
 #  --------------------------------------------------------------------------
 #  Source file provided under Apache License, Version 2.0, January 2004,
 #  http://www.apache.org/licenses/
-#  (c) Copyright Xavier Nodet, 2021
+#  (c) Copyright Xavier Nodet, 2022
 #
 #  Unless required by applicable law or agreed to in writing, software
 #  distributed under the License is distributed on an "AS IS" BASIS,
@@ -35,7 +35,10 @@ from packaging import version
 from ibm_watson_machine_learning import APIClient
 
 # WML Python API version with a fixed Assets.download function
-WML_HAS_FIXED_DOWNLOAD = "1000.0.0"
+WML_HAS_FIXED_DOWNLOAD = "1.0.177"
+# WML Python API version with _asset_id to create a job
+WML_HAS_ASSET_ID_IN_CREATE_JOB = "1.0.180"
+
 
 LOGNAME = 'log.txt'
 
@@ -248,7 +251,7 @@ class DOWMLLib:
     MODEL_NAME = f'{DOWML_PREFIX}-model'
     MODEL_TYPES = ['cplex', 'cpo', 'opl', 'docplex']
     DO_VERSION = '20.1'
-    TSHIRT_SIZES = ['S', 'M', 'XL']
+    TSHIRT_SIZES = ['S', 'M', 'L', 'XL']
     DEPLOYMENT_NAME = f'{DOWML_PREFIX}-deployment'
 
     def __init__(self, wml_credentials_file=None,
@@ -417,7 +420,7 @@ class DOWMLLib:
 
         def _get_asset_content(asset_id):
             if version_is_greater(self._client.version, WML_HAS_FIXED_DOWNLOAD):
-                return self._client.data_assets.download(asset_id).decode('ascii')
+                return self._client.data_assets.get_content(asset_id).decode('ascii')
             else:
                 with tempfile.TemporaryDirectory() as temp_dir_name:
                     filename = os.path.join(temp_dir_name, f'{asset_id}-log.txt')
@@ -970,6 +973,10 @@ class DOWMLLib:
         deployment = client.deployments.get_details(deployment_id)
         return deployment
 
+    def _get_model_id_from_deployment(self, deployment_id):
+        details = self._get_deployment_from_id(deployment_id)
+        return details["entity"]["asset"]['id']
+
     def _get_size_from_details(self, job):
         try:
             deployment_id = job['entity']['deployment']['id']
@@ -1097,7 +1104,11 @@ class DOWMLLib:
         else:
             self._logger.debug(repr(solve_payload))
         dt = datetime.now()
-        job_details = client.deployments.create_job(deployment_id, solve_payload)
+        if version_is_greater(client.version, WML_HAS_ASSET_ID_IN_CREATE_JOB):
+            model_id = self._get_model_id_from_deployment(deployment_id)
+            job_details = client.deployments.create_job(deployment_id, solve_payload, _asset_id=model_id)
+        else:
+            job_details = client.deployments.create_job(deployment_id, solve_payload)
         submit_time = (datetime.now() - dt).total_seconds()
         self._logger.debug(f'Done in {submit_time}. Getting its id...')
         job_id = client.deployments.get_job_uid(job_details)
